Re-exports
pub use fixed;
Modules
- balances
- bazaar
- bip340
- bs58_
verify - ceremonies
- common
- communities
- democracy
- error
- faucet
- fixed
- Fixed-point numbers
- math
- random_
number_ generator - A simple pseudo random number generator that allows a stream of random numbers to be efficiently created from a single initial seed hash.
- random_
permutation - A simple trait that allows pseudo-random permutations on arbitrary
vecs. - reputation_
commitments - scheduler
- serde
- Custom serde serialization helpers
- storage
- Helper functions to manipulate the storage, to get a specific state in the tests
- treasuries
- vouches
Structs
- Bs58verify
- Simple Bs58 verification adapted from https://github.com/mycorrhiza/bs58-rs
- Random
Number Generator - Pseudo-random number streamer. This retains the state of the random number stream. It’s as secure as the combination of the seed with which it is constructed and the hash function it uses to cycle elements.
Enums
Traits
- AbsDiff
- Random
Permutation - Pseudo-random permutation. It’s as secure as the combination of the seed with which the RandomNumberGenerator is constructed and the hash function it uses to cycle the elements.